summaryrefslogtreecommitdiff
path: root/src/xkbcomp/keymap.c
diff options
context:
space:
mode:
authorRan Benita <ran234@gmail.com>2013-02-17 22:18:57 +0200
committerDaniel Stone <daniel@fooishbar.org>2013-03-18 22:20:02 +0000
commit8cee7490003381b7e1399e171a8c860edb3d634c (patch)
tree5cb829b303322446fa72bf250ba037ab9200b75f /src/xkbcomp/keymap.c
parent10c351f5163ff8ce3be232207bf9c0f68fbbb47d (diff)
downloadlibxkbcommon-8cee7490003381b7e1399e171a8c860edb3d634c.tar.gz
libxkbcommon-8cee7490003381b7e1399e171a8c860edb3d634c.tar.bz2
libxkbcommon-8cee7490003381b7e1399e171a8c860edb3d634c.zip
Change 'indicator' to 'led' everywhere possible
The code currently uses the two names interchangeably. Settle on 'led', because it is shorter, more recognizable, and what we use in our API (though of course the parser still uses 'indicator'). In camel case we make it 'Led'. We change 'xkb_indicator_map' to just 'xkb_led' and the variables of this type are 'led'. This mimics 'xkb_key' and 'key'. IndicatorNameInfo and LEDInfo are changed to 'LedNameInfo' and 'LedInfo', and the variables are 'ledi' (like 'keyi' etc.). This is instead of 'ii' and 'im'. This might make a few places a bit confusing, but less than before I think. It's also shorter. Signed-off-by: Ran Benita <ran234@gmail.com>
Diffstat (limited to 'src/xkbcomp/keymap.c')
-rw-r--r--src/xkbcomp/keymap.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/xkbcomp/keymap.c b/src/xkbcomp/keymap.c
index a3503b8..1d69245 100644
--- a/src/xkbcomp/keymap.c
+++ b/src/xkbcomp/keymap.c
@@ -180,7 +180,7 @@ static bool
UpdateDerivedKeymapFields(struct xkb_keymap *keymap)
{
struct xkb_mod *mod;
- struct xkb_indicator_map *im;
+ struct xkb_led *led;
unsigned int i, j;
struct xkb_key *key;
@@ -213,9 +213,9 @@ UpdateDerivedKeymapFields(struct xkb_keymap *keymap)
UpdateActionMods(keymap, &key->groups[i].levels[j].action,
key->modmap);
- /* Update vmod -> indicator maps. */
- darray_foreach(im, keymap->indicators)
- ComputeEffectiveMask(keymap, &im->mods);
+ /* Update vmod -> led maps. */
+ darray_foreach(led, keymap->leds)
+ ComputeEffectiveMask(keymap, &led->mods);
/* Find maximum number of groups out of all keys in the keymap. */
xkb_foreach_key(key, keymap)